
#line 3 "lex.yy.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else   /* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif  /* defined (__STDC__) */
#endif  /* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart(yyin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

extern int yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
        do \
                { \
                /* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
                *yy_cp = (yy_hold_char); \
                YY_RESTORE_YY_MORE_OFFSET \
                (yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
                YY_DO_BEFORE_ACTION; /* set up yytext again */ \
                } \
        while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
        {
        FILE *yy_input_file;

        char *yy_ch_buf;                /* input buffer */
        char *yy_buf_pos;               /* current position in input buffer */

        /* Size of input buffer in bytes, not including room for EOB
         * characters.
         */
        yy_size_t yy_buf_size;

        /* Number of characters read into yy_ch_buf, not including EOB
         * characters.
         */
        int yy_n_chars;

        /* Whether we "own" the buffer - i.e., we know we created it,
         * and can realloc() it to grow it, and should free() it to
         * delete it.
         */
        int yy_is_our_buffer;

        /* Whether this is an "interactive" input source; if so, and
         * if we're using stdio for input, then we want to use getc()
         * instead of fread(), to make sure we stop fetching input after
         * each newline.
         */
        int yy_is_interactive;

        /* Whether we're considered to be at the beginning of a line.
         * If so, '^' rules will be active on the next match, otherwise
         * not.
         */
        int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
        /* Whether to try to fill the input buffer when we reach the
         * end of it.
         */
        int yy_fill_buffer;

        int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
        /* When an EOF's been seen but there's still some text to process
         * then we mark the buffer as YY_EOF_PENDING, to indicate that we
         * shouldn't try reading from the input source any more.  We might
         * still have a bunch of tokens to match, though, because of
         * possible backing-up.
         *
         * When we actually see the EOF, we change the status to "new"
         * (via yyrestart()), so that the user can continue scanning by
         * just pointing yyin at a new input file.
         */
#define YY_BUFFER_EOF_PENDING 2

        };
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;          /* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;         /* whether we need to initialize */
static int yy_start = 0;        /* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart (FILE *input_file  );
void yy_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer (FILE *file,int size  );
void yy_delete_buffer (YY_BUFFER_STATE b  );
void yy_flush_buffer (YY_BUFFER_STATE b  );
void yypush_buffer_state (YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state (void );

static void yyensure_buffer_stack (void );
static void yy_load_buffer_state (void );
static void yy_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER yy_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE yy_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes (yyconst char *bytes,int len  );

void *yyalloc (yy_size_t  );
void *yyrealloc (void *,yy_size_t  );
void yyfree (void *  );

#define yy_new_buffer yy_create_buffer

#define yy_set_interactive(is_interactive) \
        { \
        if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
                YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
        } \
        YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
        }

#define yy_set_bol(at_bol) \
        { \
        if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
                YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
        } \
        YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
        }

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define yywrap(n) 1
#define YY_SKIP_YYWRAP

typedef unsigned char YY_CHAR;

FILE *yyin = (FILE *) 0, *yyout = (FILE *) 0;

typedef int yy_state_type;

extern int yylineno;

int yylineno = 1;

extern char *yytext;
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
        (yytext_ptr) = yy_bp; \
        yyleng = (size_t) (yy_cp - yy_bp); \
        (yy_hold_char) = *yy_cp; \
        *yy_cp = '\0'; \
        (yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 80
#define YY_END_OF_BUFFER 81
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
        {
        flex_int32_t yy_verify;
        flex_int32_t yy_nxt;
        };
static yyconst flex_int16_t yy_accept[422] =
    {   0,
       76,   76,   76,   76,   76,   76,   81,   79,   76,   80,
       79,   79,   79,   79,   55,   53,   79,   79,   79,   49,
       49,   49,   79,   49,   49,   49,   49,   49,   49,   49,
       49,   49,   49,   49,   49,   49,   49,   49,   49,   49,
       76,   79,   78,   79,   55,   53,   77,   79,   55,   53,
       49,   76,    0,   56,    0,    0,    0,   55,   53,   75,
        0,   55,    0,    0,    0,   53,   48,   46,   47,   49,
       49,   49,   49,   49,   49,   49,   49,   49,   49,   49,
       49,   49,   49,   49,   49,   49,   41,   49,   49,   49,
       49,   49,   49,   49,   49,   49,   49,   49,   49,   49,

       49,   49,   49,   49,   49,   49,   49,   49,   49,   76,
        0,    0,   72,    0,    0,    0,    0,    0,   55,   53,
       51,   55,    0,   53,   55,   53,    0,   55,    0,   53,
       49,   56,   57,    0,   57,    0,    0,   74,    0,   52,
       54,   49,   49,   49,   49,   49,   49,   49,   49,   49,
       49,   49,   49,   49,   49,   49,   49,   49,   49,   49,
       49,   49,   49,   49,   42,   49,   49,   49,   49,   49,
       49,   49,   49,   49,   49,   49,   49,   49,   49,   49,
       49,   49,    0,    0,    0,    0,    0,    0,   51,    0,
       51,   50,   49,   59,   58,    0,   52,   49,   38,   49,

       49,   49,   18,   25,   49,   49,   49,   49,   49,   12,
       49,   49,   49,   49,   49,   49,   22,   49,   49,   49,
       49,   49,   49,   49,   49,   49,   49,   49,   49,   49,
       49,   49,   49,   49,   49,   49,   29,   49,   49,    0,
        0,    0,    0,    0,    0,   51,   45,   58,    0,   39,
       49,   49,   49,    9,   49,   49,   49,   49,   49,   49,
       20,   40,   49,    7,   49,   28,   49,   49,   49,   49,
       49,   49,   49,   23,   49,   49,   49,   49,   49,   49,
       16,   49,   49,   26,   49,   71,    0,    0,    0,    0,
       49,   49,   49,   49,   30,   49,   21,   49,   49,   49,

        1,   43,   44,   49,   34,    2,   49,   49,   13,   11,
       49,   17,   49,   49,   49,   49,   49,   69,    0,    0,
        0,    0,    0,    0,   49,   49,   27,    6,   19,   49,
       36,   49,   35,   49,   49,   49,   49,   10,   49,   49,
       14,   70,    0,    0,   73,    0,    0,   68,    0,    0,
       67,   37,   49,   49,   49,    3,   15,   33,   49,   24,
       49,    0,    0,    0,    0,    0,    0,    0,    4,    5,
        8,   49,   31,   63,    0,    0,    0,    0,   49,   65,
        0,    0,    0,   32,    0,    0,    0,    0,    0,    0,
        0,   64,    0,    0,   66,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,   60,
        0,    0,    0,    0,    0,    0,    0,    0,   61,   62,
        0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    5,    1,    6,    7,    1,    1,    1,    8,    1,
        1,    9,   10,    1,   11,   12,   13,   14,   15,   15,
       15,   15,   15,   15,   15,   16,   16,   17,    1,   18,
        1,   19,    1,    1,   20,   21,   21,   22,   23,   24,
       25,   25,   26,   25,   25,   27,   25,   25,   25,   25,
       25,   28,   29,   30,   31,   25,   25,   32,   25,   25,
        1,   33,    1,    1,   34,    1,   35,   36,   37,   38,

       39,   40,   41,   42,   43,   25,   25,   44,   45,   46,
       47,   48,   49,   50,   51,   52,   53,   54,   55,   56,
       57,   25,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[58] =
    {   0,
        1,    1,    2,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    3,    3,    3,    1,    1,    1,    4,
        4,    4,    4,    4,    5,    5,    5,    5,    5,    5,
        5,    5,    1,    6,    4,    4,    4,    4,    4,    4,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5
    } ;

static yyconst flex_int16_t yy_base[432] =
    {   0,
        0,   56,   56,   71,   77,  116,  736,  737,   60,  737,
       62,  702,   82,   66,   90,   85,  717,  715,  713,    0,
      711,  702,    0,   58,  682,   67,   30,   69,   46,  682,
      680,  679,   89,   83,   68,   99,   90,  679,   81,   97,
      153,  159,  737,  129,  153,  165,  737,  156,  182,  196,
      143,  211,   78,  737,  106,  716,  175,  208,  211,  737,
      720,  214,  228,  244,    0,  247,  737,  737,  737,    0,
      695,  690,    0,  669,  667,  671,  666,  681,  669,  663,
      673,  659,  658,  673,  672,  661,  139,  113,  669,  654,
      666,  669,  651,  659,  665,  657,  664,  649,  650,  646,

      647,  651,  640,  644,  190,  647,  647,  647,  636,  264,
      234,    0,  737,  681,  269,  648,  642,  634,  264,  276,
      307,  286,  296,  325,  338,  343,  185,  353,  372,  384,
      636,  212,  737,  674,  673,  299,  677,  737,  279,  388,
        0,  650,  655,  625,  626,  631,  635,  623,  197,  620,
      636,  634,  624,  629,  615,  631,  612,  625,  628,  621,
      608,  621,  604,  609,    0,  603,  612,  604,  616,  600,
      602,  110,  603,  598,  603,  609,  600,  603,  592,  606,
      608,  592,  324,  635,  634,  600,  592,  602,    0,  364,
      737,  290,  591,  737,  737,  328,  737,  612,    0,  584,

      590,  593,    0,    0,  579,  591,  582,  575,  583,    0,
      578,  578,  572,  571,  572,  577,    0,  576,  567,  583,
      564,  581,  572,  575,  566,  573,  559,  564,  572,  561,
      570,  569,  567,  558,  562,  563,    0,  551,  557,  593,
      179,  552,  558,  555,  302,  394,    0,  737,  587,    0,
      559,  557,  557,    0,  535,  545,  515,  508,  486,  487,
        0,    0,  496,    0,  496,    0,  477,  493,  479,  493,
      478,  482,  481,    0,  485,  472,  473,  479,  483,  478,
        0,  470,  463,    0,  468,  737,  411,  461,  415,  467,
      473,  456,  461,  453,    0,  452,    0,  460,  445,  466,

        0,    0,    0,  461,    0,    0,  455,  461,    0,    0,
      444,    0,  443,  454,  454,  435,  450,  737,  421,  436,
      486,  440,  444,  453,  434,  430,    0,    0,    0,  431,
        0,  440,    0,  418,  430,  412,  427,    0,  423,  409,
        0,  737,  450,  445,  737,  444,  465,  737,  469,  441,
      471,    0,  401,  387,  383,    0,    0,    0,  383,    0,
      374,  403,  485,  383,  355,  349,  343,  352,    0,    0,
        0,  346,    0,  737,  332,  337,  344,  331,  334,  737,
      330,  323,  311,    0,  321,  313,  306,  299,  288,  291,
      299,  737,  286,  222,  737,  277,  281,  267,  260,  243,

      237,  240,  222,  239,  218,  169,  213,  202,  193,  737,
      174,  145,  127,   95,   43,   44,   14,   10,  737,  737,
      737,  539,  545,  549,  552,  557,  563,  567,  571,  577,
      583
    } ;

static yyconst flex_int16_t yy_def[432] =
    {   0,
      421,    1,    1,    1,    1,    1,  421,  421,  421,  421,
      422,  423,  421,  421,  421,  421,  421,  421,  421,  424,
      424,  424,  425,  424,  424,  424,  424,  424,  424,  424,
      424,  424,  424,  424,  424,  424,  424,  424,  424,  424,
      421,  421,  421,  421,  421,  421,  421,  421,  421,  421,
      424,  421,  422,  421,  422,  421,  426,  421,  421,  421,
      427,  421,  421,  421,  428,  421,  421,  421,  421,  424,
      424,  424,  424,  424,  424,  424,  424,  424,  424,  424,
      424,  424,  424,  424,  424,  424,  424,  424,  424,  424,
      424,  424,  424,  424,  424,  424,  424,  424,  424,  424,

      424,  424,  424,  424,  424,  424,  424,  424,  424,  421,
      421,   42,  421,   42,  421,  421,  421,  421,  421,  421,
      421,  421,  421,  421,  421,  421,  421,  421,  421,  421,
      424,  422,  421,  421,  421,  421,  427,  421,  421,  421,
      428,  424,  424,  424,  424,  424,  424,  424,  424,  424,
      424,  424,  424,  424,  424,  424,  424,  424,  424,  424,
      424,  424,  424,  424,  424,  424,  424,  424,  424,  424,
      424,  424,  424,  424,  424,  424,  424,  424,  424,  424,
      424,  424,  421,  429,  421,  421,  421,  421,  121,  421,
      421,  421,  424,  421,  421,  421,  421,  424,  424,  424,

      424,  424,  424,  424,  424,  424,  424,  424,  424,  424,
      424,  424,  424,  424,  424,  424,  424,  424,  424,  424,
      424,  424,  424,  424,  424,  424,  424,  424,  424,  424,
      424,  424,  424,  424,  424,  424,  424,  424,  424,  429,
      421,  421,  421,  421,  421,  421,  424,  421,  421,  424,
      424,  424,  424,  424,  424,  424,  424,  424,  424,  424,
      424,  424,  424,  424,  424,  424,  424,  424,  424,  424,
      424,  424,  424,  424,  424,  424,  424,  424,  424,  424,
      424,  424,  424,  424,  424,  421,  421,  421,  421,  421,
      424,  424,  424,  424,  424,  424,  424,  424,  424,  424,

      424,  424,  424,  424,  424,  424,  424,  424,  424,  424,
      424,  424,  424,  424,  424,  424,  424,  421,  421,  421,
      430,  431,  421,  421,  424,  424,  424,  424,  424,  424,
      424,  424,  424,  424,  424,  424,  424,  424,  424,  424,
      424,  421,  421,  430,  421,  431,  431,  421,  431,  431,
      421,  424,  424,  424,  424,  424,  424,  424,  424,  424,
      424,  431,  421,  421,  421,  421,  421,  421,  424,  424,
      424,  424,  424,  421,  421,  421,  421,  421,  424,  421,
      421,  421,  421,  424,  421,  421,  421,  421,  421,  421,
      421,  421,  421,  421,  421,  421,  421,  421,  421,  421,

      421,  421,  421,  421,  421,  421,  421,  421,  421,  421,
      421,  421,  421,  421,  421,  421,  421,  421,  421,  421,
        0,  421,  421,  421,  421,  421,  421,  421,  421,  421,
      421
    } ;

static yyconst flex_int16_t yy_nxt[795] =
    {   0,
        8,    9,   10,    9,    9,   11,    8,   12,    8,    8,
       13,    8,   14,   15,   16,   16,   17,   18,   19,   20,
       20,   20,   20,   21,   20,   20,   20,   20,   20,   22,
       20,   20,    8,   23,   24,   25,   26,   27,   28,   29,
       20,   20,   30,   31,   32,   20,   33,   34,   20,   35,
       36,   37,   38,   39,   40,   20,   20,   41,   43,  420,
       41,   52,   42,   52,   52,  419,   44,   54,   81,   45,
       46,   46,   41,   43,   60,   41,   82,   42,   61,   47,
       85,   44,  418,   54,   45,   46,   46,   48,  417,   86,
       49,   50,   50,   74,   55,   58,   59,   59,   66,   66,

       66,   77,   96,   62,   62,   63,   97,   64,   78,   75,
       55,  132,   64,   79,   83,  106,   51,   41,   47,   80,
       41,   65,   42,   64,   84,   90,   48,  107,   64,   49,
       50,   50,   94,  108,   91,   95,   92,   98,   55,  103,
       99,   93,  119,  120,  120,   65,  104,  109,  416,  159,
      100,  101,  228,  102,  110,   51,   52,  110,  160,  111,
      112,  113,  229,  114,  121,  415,  122,  122,  123,  125,
      126,  126,  115,  115,  115,   64,  121,   85,  124,  124,
      124,  286,  135,  287,   65,  157,   86,   64,  136,  136,
      158,   64,  131,  127,  414,  128,  128,  129,  192,  192,

      192,  116,  117,   64,   64,  408,  118,  127,   65,  130,
      130,  130,   52,   65,   52,   52,  413,   54,   64,  409,
       64,   62,   62,   63,   66,   66,   66,   62,   62,   63,
       64,  412,  177,   64,   64,  183,   64,   65,  183,   65,
      178,   63,   63,   63,   55,  411,   64,  205,  206,   64,
       64,  410,   64,  139,  139,  407,  396,  140,  140,  140,
       66,   66,   66,   65,  397,  110,   64,   52,  110,   64,
      111,  113,  406,  185,  405,  121,  404,  122,  122,  123,
      403,  118,  115,  115,  115,   64,   64,  121,  402,  124,
      124,  124,  140,  140,  140,   65,  401,  121,   64,  122,

      122,  123,   64,  192,  192,  192,  195,  121,   64,  123,
      123,  123,  196,  196,   64,  246,  246,  246,   64,   65,
      189,  189,  189,  400,   64,  183,  399,  398,  183,  190,
      191,  395,  394,  191,   64,  248,  121,  393,  124,  124,
      124,  249,  249,  392,  391,  190,  191,   64,  390,  127,
      191,  128,  128,  129,  127,  389,  130,  130,  130,  388,
       64,  387,  386,   64,  127,   64,  128,  128,  129,   65,
      385,  118,  384,  245,  245,   64,   64,  246,  246,  246,
      383,   64,  382,  127,  381,  129,  129,  129,  380,  379,
      378,   64,  377,   65,   64,  127,  376,  130,  130,  130,

      375,  140,  140,  140,  374,  348,   64,  246,  246,  246,
       64,  197,  373,  318,  197,  319,  322,  191,  372,  322,
      191,  371,   64,  342,  320,  320,  320,  197,  323,  323,
      323,  197,  370,  191,  343,  343,  343,  191,  318,  369,
      319,  347,  348,  348,  347,  350,  348,  345,  350,  320,
      320,  320,  342,  349,  349,  349,  361,  323,  323,  323,
      360,  359,  358,  343,  343,  343,  347,  348,  357,  347,
      362,  348,  363,  362,  356,  363,  355,  354,  349,  349,
      349,  353,  349,  349,  349,  352,  363,  351,  345,  363,
      341,  340,  339,  338,  337,  336,  364,  335,  334,  333,

      332,  331,  330,  329,  328,  365,  327,  366,  326,  325,
      364,  324,  321,  317,  316,  315,  314,  313,  367,  365,
      312,  366,  311,  310,  368,  309,  308,  307,  306,  305,
      304,  303,  367,  302,  301,  300,  299,  298,  368,   53,
       53,   53,   53,   53,   53,   56,  297,   56,   56,   56,
       56,   70,   70,   70,   70,   73,   73,  134,  296,  134,
      134,  134,  134,  137,  137,  137,  137,  137,  137,  141,
      141,  240,  240,  240,  240,  240,  240,  344,  344,  344,
      344,  344,  344,  346,  346,  346,  346,  346,  346,  295,
      294,  293,  292,  291,  248,  290,  289,  288,  241,  285,

      284,  283,  282,  281,  280,  279,  278,  277,  276,  275,
      274,  273,  272,  271,  270,  269,  268,  267,  266,  265,
      264,  263,  262,  261,  260,  259,  258,  257,  256,  255,
      254,  253,  252,  251,  250,  247,  244,  243,  242,  184,
      241,  239,  238,  237,  236,  235,  234,  233,  232,  231,
      230,  227,  226,  225,  224,  223,  222,  221,  220,  219,
      218,  217,  216,  215,  214,  213,  212,  211,  210,  209,
      208,  207,  204,  203,  202,  201,  200,  199,  198,  138,
      194,  194,  193,  188,  187,  186,  184,  182,  181,  180,
      179,  176,  175,  174,  173,  172,  171,  170,  169,  168,

      167,  166,  165,  164,  163,  162,  161,  156,  155,  154,
      153,  152,  151,  150,  149,  148,  147,  146,  145,  144,
      143,  142,  138,  133,  105,   89,   88,   87,   76,   72,
       71,   69,   68,   67,   57,  421,    7,  421,  421,  421,
      421,  421,  421,  421,  421,  421,  421,  421,  421,  421,
      421,  421,  421,  421,  421,  421,  421,  421,  421,  421,
      421,  421,  421,  421,  421,  421,  421,  421,  421,  421,
      421,  421,  421,  421,  421,  421,  421,  421,  421,  421,
      421,  421,  421,  421,  421,  421,  421,  421,  421,  421,
      421,  421,  421,  421

    } ;

static yyconst flex_int16_t yy_chk[795] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    2,    3,  418,
        2,    9,    2,    9,    9,  417,    3,   11,   27,    3,
        3,    3,    4,    4,   14,    4,   27,    4,   14,    5,
       29,    4,  416,   53,    4,    4,    4,    5,  415,   29,
        5,    5,    5,   24,   11,   13,   13,   13,   16,   16,

       16,   26,   35,   15,   15,   15,   35,   16,   26,   24,
       53,   55,   15,   26,   28,   39,    5,    6,    6,   26,
        6,   15,    6,   16,   28,   33,    6,   39,   15,    6,
        6,    6,   34,   40,   33,   34,   33,   36,   55,   37,
       36,   33,   44,   44,   44,   15,   37,   40,  414,   88,
       36,   36,  172,   36,   41,    6,   41,   41,   88,   41,
       42,   42,  172,   42,   45,  413,   45,   45,   45,   48,
       48,   48,   42,   42,   42,   45,   46,   51,   46,   46,
       46,  241,   57,  241,   45,   87,   51,   46,   57,   57,
       87,   45,   51,   49,  412,   49,   49,   49,  127,  127,

      127,   42,   42,   46,   49,  406,   42,   50,   45,   50,
       50,   50,   52,   49,   52,   52,  411,  132,   50,  406,
       49,   58,   58,   58,   59,   59,   59,   62,   62,   62,
       58,  409,  105,   59,   50,  111,   62,   49,  111,   58,
      105,   63,   63,   63,  132,  408,   58,  149,  149,   59,
       63,  407,   62,   64,   64,  405,  394,   64,   64,   64,
       66,   66,   66,   58,  394,  110,   63,  110,  110,   66,
      110,  115,  404,  115,  403,  119,  402,  119,  119,  119,
      401,  111,  115,  115,  115,   66,  119,  120,  400,  120,
      120,  120,  139,  139,  139,  119,  399,  122,  120,  122,

      122,  122,  119,  192,  192,  192,  136,  123,  122,  123,
      123,  123,  136,  136,  120,  245,  245,  245,  123,  119,
      121,  121,  121,  398,  122,  183,  397,  396,  183,  121,
      121,  393,  391,  121,  123,  196,  124,  390,  124,  124,
      124,  196,  196,  389,  388,  121,  121,  124,  387,  125,
      121,  125,  125,  125,  126,  386,  126,  126,  126,  385,
      125,  383,  382,  124,  128,  126,  128,  128,  128,  125,
      381,  183,  379,  190,  190,  128,  125,  190,  190,  190,
      378,  126,  377,  129,  376,  129,  129,  129,  375,  372,
      368,  128,  367,  125,  129,  130,  366,  130,  130,  130,

      365,  140,  140,  140,  364,  362,  130,  246,  246,  246,
      129,  140,  361,  287,  140,  287,  289,  246,  359,  289,
      246,  355,  130,  319,  287,  287,  287,  140,  289,  289,
      289,  140,  354,  246,  319,  319,  319,  246,  320,  353,
      320,  322,  322,  350,  322,  323,  346,  344,  323,  320,
      320,  320,  343,  322,  322,  322,  340,  323,  323,  323,
      339,  337,  336,  343,  343,  343,  347,  347,  335,  347,
      349,  349,  351,  349,  334,  351,  332,  330,  347,  347,
      347,  326,  349,  349,  349,  325,  363,  324,  321,  363,
      317,  316,  315,  314,  313,  311,  351,  308,  307,  304,

      300,  299,  298,  296,  294,  351,  293,  351,  292,  291,
      363,  290,  288,  285,  283,  282,  280,  279,  351,  363,
      278,  363,  277,  276,  351,  275,  273,  272,  271,  270,
      269,  268,  363,  267,  265,  263,  260,  259,  363,  422,
      422,  422,  422,  422,  422,  423,  258,  423,  423,  423,
      423,  424,  424,  424,  424,  425,  425,  426,  257,  426,
      426,  426,  426,  427,  427,  427,  427,  427,  427,  428,
      428,  429,  429,  429,  429,  429,  429,  430,  430,  430,
      430,  430,  430,  431,  431,  431,  431,  431,  431,  256,
      255,  253,  252,  251,  249,  244,  243,  242,  240,  239,

      238,  236,  235,  234,  233,  232,  231,  230,  229,  228,
      227,  226,  225,  224,  223,  222,  221,  220,  219,  218,
      216,  215,  214,  213,  212,  211,  209,  208,  207,  206,
      205,  202,  201,  200,  198,  193,  188,  187,  186,  185,
      184,  182,  181,  180,  179,  178,  177,  176,  175,  174,
      173,  171,  170,  169,  168,  167,  166,  164,  163,  162,
      161,  160,  159,  158,  157,  156,  155,  154,  153,  152,
      151,  150,  148,  147,  146,  145,  144,  143,  142,  137,
      135,  134,  131,  118,  117,  116,  114,  109,  108,  107,
      106,  104,  103,  102,  101,  100,   99,   98,   97,   96,

       95,   94,   93,   92,   91,   90,   89,   86,   85,   84,
       83,   82,   81,   80,   79,   78,   77,   76,   75,   74,
       72,   71,   61,   56,   38,   32,   31,   30,   25,   22,
       21,   19,   18,   17,   12,    7,  421,  421,  421,  421,
      421,  421,  421,  421,  421,  421,  421,  421,  421,  421,
      421,  421,  421,  421,  421,  421,  421,  421,  421,  421,
      421,  421,  421,  421,  421,  421,  421,  421,  421,  421,
      421,  421,  421,  421,  421,  421,  421,  421,  421,  421,
      421,  421,  421,  421,  421,  421,  421,  421,  421,  421,
      421,  421,  421,  421

    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "idl.ll"
#line 5 "idl.ll"
/*

COPYRIGHT

Copyright 1992, 1993, 1994 Sun Microsystems, Inc.  Printed in the United
States of America.  All Rights Reserved.

This product is protected by copyright and distributed under the following
license restricting its use.

The Interface Definition Language Compiler Front End (CFE) is made
available for your use provided that you include this license and copyright
notice on all media and documentation and the software program in which
this product is incorporated in whole or part. You may copy and extend
functionality (but may not remove functionality) of the Interface
Definition Language CFE without charge, but you are not authorized to
license or distribute it to anyone else except as part of a product or
program developed by you or with the express written consent of Sun
Microsystems, Inc. ("Sun").

The names of Sun Microsystems, Inc. and any of its subsidiaries or
affiliates may not be used in advertising or publicity pertaining to
distribution of Interface Definition Language CFE as permitted herein.

This license is effective until terminated by Sun for failure to comply
with this license.  Upon termination, you shall destroy or return all code
and documentation for the Interface Definition Language CFE.

INTERFACE DEFINITION LANGUAGE CFE IS PROVIDED AS IS WITH NO WARRANTIES OF
ANY KIND INCLUDING THE WARRANTIES OF DESIGN, MERCHANTIBILITY AND FITNESS
FOR A PARTICULAR PURPOSE, NONINFRINGEMENT, OR ARISING FROM A COURSE OF
DEALING, USAGE OR TRADE PRACTICE.

INTERFACE DEFINITION LANGUAGE CFE IS PROVIDED WITH NO SUPPORT AND WITHOUT
ANY OBLIGATION ON THE PART OF Sun OR ANY OF ITS SUBSIDIARIES OR AFFILIATES
TO ASSIST IN ITS USE, CORRECTION, MODIFICATION OR ENHANCEMENT.

SUN OR ANY OF ITS SUBSIDIARIES OR AFFILIATES SHALL HAVE NO LIABILITY WITH
RESPECT TO THE INFRINGEMENT OF COPYRIGHTS, TRADE SECRETS OR ANY PATENTS BY
INTERFACE DEFINITION LANGUAGE CFE OR ANY PART THEREOF.

IN NO EVENT WILL SUN OR ANY OF ITS SUBSIDIARIES OR AFFILIATES BE LIABLE FOR
ANY LOST REVENUE OR PROFITS OR OTHER SPECIAL, INDIRECT AND CONSEQUENTIAL
DAMAGES, EVEN IF SUN HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.

Use, duplication, or disclosure by the government is subject to
restrictions as set forth in subparagraph (c)(1)(ii) of the Rights in
Technical Data and Computer Software clause at DFARS 252.227-7013 and FAR
52.227-19.

Sun, Sun Microsystems and the Sun logo are trademarks or registered
trademarks of Sun Microsystems, Inc.

SunSoft, Inc.  
2550 Garcia Avenue 
Mountain View, California  94043

NOTE:

SunOS, SunSoft, Sun, Solaris, Sun Microsystems or the Sun logo are
trademarks or registered trademarks of Sun Microsystems, Inc.

 */


/*
 * idl.ll - Lexical scanner for IDL 1.1
 */
#include "os_stdlib.h"
#include "os_heap.h"
#include "os_errno.h"
#include "idl.h"
#include "idl_extern.h"
#include "utl_incl.h"

#include "fe_private.h"

#ifdef VERSION
#undef VERSION
#endif

#include "y_tab.h"
#include <string.h>

#include "preprocess.h"

#undef input
#define input() ((yytchar=yysptr>yysbuf?U(*--yysptr):preprocess_getc())==10?(yylineno++,yytchar):yytchar)

#define YY_INPUT(buf,result,max_size) \
{ \
   int c = preprocess_getc(); \
   result = (c == EOF) ? YY_NULL : (buf[0] = c, 1); \
}

static char     idl_escape_reader(char *);
static long     idl_atoi(char *, long);
static void     idl_parse_line_and_file(char *);

#ifdef __cplusplus
extern "C" int fstackdepth;
#else
extern int fstackdepth;
#endif

// HPUX has yytext typed to unsigned char *. We make sure here that
// we'll always use char *
#define CPPGEN_YYTEXT ((char*) yytext)


#line 118 "idl.ll"
        /* This lets us get exclusive states */
        static int first_time = 1;
/* This tells flex to read only one input file */
/* This removes the need to wrap unistd.h in a preprocessor if block, but the
   version of flex we use does not support it. Should we upgrade to a newer
   version, please uncomment this option to remove the need for the
   lex_yy.cpp.patch file. */
#define YY_NO_UNISTD_H 1
#line 899 "lex.yy.c"

#define INITIAL 0
#define NORMAL_STATE 1
#define PRAGMA_STATE 2

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy (void );

int yyget_debug (void );

void yyset_debug (int debug_flag  );

YY_EXTRA_TYPE yyget_extra (void );

void yyset_extra (YY_EXTRA_TYPE user_defined  );

FILE *yyget_in (void );

void yyset_in  (FILE * in_str  );

FILE *yyget_out (void );

void yyset_out  (FILE * out_str  );

int yyget_leng (void );

char *yyget_text (void );

int yyget_lineno (void );

void yyset_lineno (int line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap (void );
#else
extern int yywrap (void );
#endif
#endif

    static void yyunput (int c,char *buf_ptr  );
    
#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
        if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
                { \
                int c = '*'; \
                size_t n; \
                for ( n = 0; n < max_size && \
                             (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
                        buf[n] = (char) c; \
                if ( c == '\n' ) \
                        buf[n++] = (char) c; \
                if ( c == EOF && ferror( yyin ) ) \
                        YY_FATAL_ERROR( "input in flex scanner failed" ); \
                result = n; \
                } \
        else \
                { \
                os_setErrno(0); \
                while ( (result = fread(buf, 1, max_size, yyin))==0 && ferror(yyin)) \
                        { \
                        if( os_getErrno() != EINTR) \
                                { \
                                YY_FATAL_ERROR( "input in flex scanner failed" ); \
                                break; \
                                } \
                        os_setErrno(0); \
                        clearerr(yyin); \
                        } \
                }\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
        if ( yyleng > 0 ) \
                YY_CURRENT_BUFFER_LVALUE->yy_at_bol = \
                                (yytext[yyleng - 1] == '\n'); \
        YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
        register yy_state_type yy_current_state;
        register char *yy_cp, *yy_bp;
        register int yy_act;
    
#line 130 "idl.ll"



        if(first_time)
        {
                /* ensures that we start off in the NORMAL state */
                BEGIN NORMAL_STATE;
                first_time = 0;
        }



#line 1104 "lex.yy.c"

        if ( !(yy_init) )
                {
                (yy_init) = 1;

#ifdef YY_USER_INIT
                YY_USER_INIT;
#endif

                if ( ! (yy_start) )
                        (yy_start) = 1; /* first start state */

                if ( ! yyin )
                        yyin = stdin;

                if ( ! yyout )
                        yyout = stdout;

                if ( ! YY_CURRENT_BUFFER ) {
                        yyensure_buffer_stack ();
                        YY_CURRENT_BUFFER_LVALUE =
                                yy_create_buffer(yyin,YY_BUF_SIZE );
                }

                yy_load_buffer_state( );
                }

        while ( 1 )             /* loops until end-of-file is reached */
                {
                yy_cp = (yy_c_buf_p);

                /* Support of yytext. */
                *yy_cp = (yy_hold_char);

                /* yy_bp points to the position in yy_ch_buf of the start of
                 * the current run.
                 */
                yy_bp = yy_cp;

                yy_current_state = (yy_start);
                yy_current_state += YY_AT_BOL();
yy_match:
                do
                        {
                        register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
                        if ( yy_accept[yy_current_state] )
                                {
                                (yy_last_accepting_state) = yy_current_state;
                                (yy_last_accepting_cpos) = yy_cp;
                                }
                        while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
                                {
                                yy_current_state = (int) yy_def[yy_current_state];
                                if ( yy_current_state >= 422 )
                                        yy_c = yy_meta[(unsigned int) yy_c];
                                }
                        yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
                        ++yy_cp;
                        }
                while ( yy_base[yy_current_state] != 737 );

yy_find_action:
                yy_act = yy_accept[yy_current_state];
                if ( yy_act == 0 )
                        { /* have to back up */
                        yy_cp = (yy_last_accepting_cpos);
                        yy_current_state = (yy_last_accepting_state);
                        yy_act = yy_accept[yy_current_state];
                        }

                YY_DO_BEFORE_ACTION;

do_action:      /* This label is used only to access EOF actions. */

                switch ( yy_act )
        { /* beginning of action switch */
                        case 0: /* must back up */
                        /* undo the effects of YY_DO_BEFORE_ACTION */
                        *yy_cp = (yy_hold_char);
                        yy_cp = (yy_last_accepting_cpos);
                        yy_current_state = (yy_last_accepting_state);
                        goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 142 "idl.ll"
return MODULE;
        YY_BREAK
case 2:
YY_RULE_SETUP
#line 143 "idl.ll"
return RAISES;
        YY_BREAK
case 3:
YY_RULE_SETUP
#line 144 "idl.ll"
return READONLY;
        YY_BREAK
case 4:
YY_RULE_SETUP
#line 145 "idl.ll"
return ATTRIBUTE;
        YY_BREAK
case 5:
YY_RULE_SETUP
#line 146 "idl.ll"
return EXCEPTION;
        YY_BREAK
case 6:
YY_RULE_SETUP
#line 147 "idl.ll"
return IDL_CONTEXT;
        YY_BREAK
case 7:
YY_RULE_SETUP
#line 148 "idl.ll"
return LOCAL;
        YY_BREAK
case 8:
YY_RULE_SETUP
#line 149 "idl.ll"
return INTERFACE;
        YY_BREAK
case 9:
YY_RULE_SETUP
#line 150 "idl.ll"
return CONST;
        YY_BREAK
case 10:
YY_RULE_SETUP
#line 151 "idl.ll"
return TYPEDEF;
        YY_BREAK
case 11:
YY_RULE_SETUP
#line 152 "idl.ll"
return STRUCT;
        YY_BREAK
case 12:
YY_RULE_SETUP
#line 153 "idl.ll"
return ENUM;
        YY_BREAK
case 13:
YY_RULE_SETUP
#line 154 "idl.ll"
return STRING;
        YY_BREAK
case 14:
YY_RULE_SETUP
#line 155 "idl.ll"
return WSTRING;
        YY_BREAK
case 15:
YY_RULE_SETUP
#line 156 "idl.ll"
return SEQUENCE;
        YY_BREAK
case 16:
YY_RULE_SETUP
#line 157 "idl.ll"
return UNION;
        YY_BREAK
case 17:
YY_RULE_SETUP
#line 158 "idl.ll"
return SWITCH;
        YY_BREAK
case 18:
YY_RULE_SETUP
#line 159 "idl.ll"
return CASE;
        YY_BREAK
case 19:
YY_RULE_SETUP
#line 160 "idl.ll"
return DEFAULT;
        YY_BREAK
case 20:
YY_RULE_SETUP
#line 161 "idl.ll"
return IDL_FLOAT;
        YY_BREAK
case 21:
YY_RULE_SETUP
#line 162 "idl.ll"
return IDL_DOUBLE;
        YY_BREAK
case 22:
YY_RULE_SETUP
#line 163 "idl.ll"
return IDL_LONG;
        YY_BREAK
case 23:
YY_RULE_SETUP
#line 164 "idl.ll"
return IDL_SHORT;
        YY_BREAK
case 24:
YY_RULE_SETUP
#line 165 "idl.ll"
return UNSIGNED;
        YY_BREAK
case 25:
YY_RULE_SETUP
#line 166 "idl.ll"
return IDL_CHAR;
        YY_BREAK
case 26:
YY_RULE_SETUP
#line 167 "idl.ll"
return IDL_WCHAR;
        YY_BREAK
case 27:
YY_RULE_SETUP
#line 168 "idl.ll"
return IDL_BOOLEAN;
        YY_BREAK
case 28:
YY_RULE_SETUP
#line 169 "idl.ll"
return IDL_OCTET;
        YY_BREAK
case 29:
YY_RULE_SETUP
#line 170 "idl.ll"
return VOID;
        YY_BREAK
case 30:
YY_RULE_SETUP
#line 172 "idl.ll"
return CUSTOM;
        YY_BREAK
case 31:
YY_RULE_SETUP
#line 173 "idl.ll"
return VALUETYPE;
        YY_BREAK
case 32:
YY_RULE_SETUP
#line 174 "idl.ll"
return TRUNCATABLE;
        YY_BREAK
case 33:
YY_RULE_SETUP
#line 175 "idl.ll"
return SUPPORTS;
        YY_BREAK
case 34:
YY_RULE_SETUP
#line 176 "idl.ll"
return IDL_PUBLIC;
        YY_BREAK
case 35:
YY_RULE_SETUP
#line 177 "idl.ll"
return IDL_PRIVATE;
        YY_BREAK
case 36:
YY_RULE_SETUP
#line 178 "idl.ll"
return FACTORY;
        YY_BREAK
case 37:
YY_RULE_SETUP
#line 179 "idl.ll"
return ABSTRACT;
        YY_BREAK
case 38:
YY_RULE_SETUP
#line 181 "idl.ll"
return TRUETOK;
        YY_BREAK
case 39:
YY_RULE_SETUP
#line 182 "idl.ll"
return FALSETOK;
        YY_BREAK
case 40:
YY_RULE_SETUP
#line 184 "idl.ll"
return INOUT;
        YY_BREAK
case 41:
YY_RULE_SETUP
#line 185 "idl.ll"
return IN;
        YY_BREAK
case 42:
YY_RULE_SETUP
#line 186 "idl.ll"
return OUT;
        YY_BREAK
case 43:
YY_RULE_SETUP
#line 187 "idl.ll"
return ONEWAY;
        YY_BREAK
case 44:
YY_RULE_SETUP
#line 188 "idl.ll"
return OPAQUE;
        YY_BREAK
case 45:
YY_RULE_SETUP
#line 190 "idl.ll"
return PFROM;
        YY_BREAK
case 46:
YY_RULE_SETUP
#line 192 "idl.ll"
return LEFT_SHIFT;
        YY_BREAK
case 47:
YY_RULE_SETUP
#line 193 "idl.ll"
return RIGHT_SHIFT;
        YY_BREAK
case 48:
YY_RULE_SETUP
#line 195 "idl.ll"
{
                  yylval.strval = strdup ("::");
                  return SCOPE_DELIMITOR;
                }
        YY_BREAK
case 49:
YY_RULE_SETUP
#line 201 "idl.ll"
{
   yylval.strval = fe_cpp_keyword (CPPGEN_YYTEXT);
   return IDENTIFIER;
}
        YY_BREAK
case 50:
YY_RULE_SETUP
#line 206 "idl.ll"
{
   char *z = (char *) os_malloc(strlen(CPPGEN_YYTEXT) + 1);
   strcpy (z, CPPGEN_YYTEXT);
   yylval.strval = z;
   BEGIN NORMAL_STATE;
   return VERSION;
}
        YY_BREAK
case 51:
YY_RULE_SETUP
#line 214 "idl.ll"
{
                  yylval.strval = CPPGEN_YYTEXT;
                  return FLOATING_PT_LITERAL;
                }
        YY_BREAK
case 52:
YY_RULE_SETUP
#line 218 "idl.ll"
{
                  yylval.strval = CPPGEN_YYTEXT;
                  return FLOATING_PT_LITERAL;
                }
        YY_BREAK
case 53:
YY_RULE_SETUP
#line 223 "idl.ll"
{
                  yylval.ival = idl_atoi(CPPGEN_YYTEXT, 10);
                  return INTEGER_LITERAL;
                }
        YY_BREAK
case 54:
YY_RULE_SETUP
#line 227 "idl.ll"
{
                  yylval.ival = idl_atoi(CPPGEN_YYTEXT, 16);
                  return INTEGER_LITERAL;
                }
        YY_BREAK
case 55:
YY_RULE_SETUP
#line 231 "idl.ll"
{
                  yylval.ival = idl_atoi(CPPGEN_YYTEXT, 8);
                  return INTEGER_LITERAL;
                }
        YY_BREAK
case 56:
/* rule 56 can match eol */
YY_RULE_SETUP
#line 236 "idl.ll"
{
                  CPPGEN_YYTEXT[strlen(CPPGEN_YYTEXT)-1] = '\0';
                  yylval.sval = new UTL_String(CPPGEN_YYTEXT + 1);
                  return STRING_LITERAL;
                }
        YY_BREAK
case 57:
YY_RULE_SETUP
#line 241 "idl.ll"
{
                  yylval.cval = CPPGEN_YYTEXT[1];
                  return CHARACTER_LITERAL;
                }
        YY_BREAK
case 58:
YY_RULE_SETUP
#line 245 "idl.ll"
{
                  // octal character constant
                  yylval.cval = idl_escape_reader(CPPGEN_YYTEXT + 1);
                  return CHARACTER_LITERAL;
                }
        YY_BREAK
case 59:
YY_RULE_SETUP
#line 250 "idl.ll"
{
                  yylval.cval = idl_escape_reader(CPPGEN_YYTEXT + 1);
                  return CHARACTER_LITERAL;
                }
        YY_BREAK
case 60:
YY_RULE_SETUP
#line 254 "idl.ll"
{/* pragma include */
                        BEGIN PRAGMA_STATE;
                        return PRAGMA_INCLUDE;
                }
        YY_BREAK
case 61:
YY_RULE_SETUP
#line 258 "idl.ll"
{/* pragma async */
                        BEGIN PRAGMA_STATE;
                        return PRAGMA_ASYNC_CLIENT;
                }
        YY_BREAK
case 62:
YY_RULE_SETUP
#line 262 "idl.ll"
{/* pragma async */
                        BEGIN PRAGMA_STATE;
                        return PRAGMA_ASYNC_SERVER;
                }
        YY_BREAK
case 63:
YY_RULE_SETUP
#line 266 "idl.ll"
{/* pragma ID */
                        BEGIN PRAGMA_STATE;
                        return PRAGMA_ID;
                }
        YY_BREAK
case 64:
YY_RULE_SETUP
#line 270 "idl.ll"
{/* pragma prefix */
                        BEGIN PRAGMA_STATE;
                        return PRAGMA_PREFIX;
                }
        YY_BREAK
case 65:
YY_RULE_SETUP
#line 274 "idl.ll"
{/* pragma any */
            BEGIN PRAGMA_STATE;
                        return PRAGMA_ANY;
                }
        YY_BREAK
case 66:
YY_RULE_SETUP
#line 278 "idl.ll"
{/* pragma version */
                        BEGIN PRAGMA_STATE;
                        return PRAGMA_VERSION;
                }
        YY_BREAK
case 67:
YY_RULE_SETUP
#line 282 "idl.ll"
{
   /* unrecognized pragma */
   BEGIN PRAGMA_STATE;
   return PRAGMA;
}
        YY_BREAK
case 68:
/* rule 68 can match eol */
YY_RULE_SETUP
#line 288 "idl.ll"
{
            idl_parse_line_and_file(CPPGEN_YYTEXT);
      }
        YY_BREAK
case 69:
/* rule 69 can match eol */
YY_RULE_SETUP
#line 291 "idl.ll"
{
                  idl_parse_line_and_file(CPPGEN_YYTEXT);
                }
        YY_BREAK
case 70:
/* rule 70 can match eol */
YY_RULE_SETUP
#line 294 "idl.ll"
{
        idl_parse_line_and_file(CPPGEN_YYTEXT);
      }
        YY_BREAK
case 71:
/* rule 71 can match eol */
YY_RULE_SETUP
#line 297 "idl.ll"
{
                  idl_parse_line_and_file(CPPGEN_YYTEXT);
                }
        YY_BREAK
case 72:
/* rule 72 can match eol */
YY_RULE_SETUP
#line 300 "idl.ll"
{
                  idl_parse_line_and_file(CPPGEN_YYTEXT);
                }
        YY_BREAK
case 73:
/* rule 73 can match eol */
YY_RULE_SETUP
#line 303 "idl.ll"
{
                  /* ignore cpp ident */
                  idl_global->set_lineno(idl_global->lineno() + 1);
                }
        YY_BREAK
case 74:
/* rule 74 can match eol */
YY_RULE_SETUP
#line 307 "idl.ll"
{
                  /* ignore comments */
                  idl_global->set_lineno(idl_global->lineno() + 1);
                }
        YY_BREAK
case 75:
YY_RULE_SETUP
#line 311 "idl.ll"
{
                  for(;;) {
                    char c = yyinput();
                    if (c == '*') {
                      char next = yyinput();
                      if (next == '/')
                        break;
                      else
                        unput(c);
                      if (c == '\n') 
                        idl_global->set_lineno(idl_global->lineno() + 1);
                    }
                  }
                }
        YY_BREAK
case 76:
YY_RULE_SETUP
#line 325 "idl.ll"
;
        YY_BREAK
case 77:
/* rule 77 can match eol */
YY_RULE_SETUP
#line 327 "idl.ll"
{
   idl_global->set_lineno (idl_global->lineno () + 1);
   BEGIN NORMAL_STATE;
   return PRAGMA_END;
}
        YY_BREAK
case 78:
/* rule 78 can match eol */
YY_RULE_SETUP
#line 333 "idl.ll"
{
   idl_global->set_lineno (idl_global->lineno () + 1);
}
        YY_BREAK
case 79:
YY_RULE_SETUP
#line 337 "idl.ll"
return CPPGEN_YYTEXT[0];
        YY_BREAK
case 80:
YY_RULE_SETUP
#line 339 "idl.ll"
ECHO;
        YY_BREAK
#line 1699 "lex.yy.c"
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(NORMAL_STATE):
case YY_STATE_EOF(PRAGMA_STATE):
        yyterminate();

        case YY_END_OF_BUFFER:
                {
                /* Amount of text matched not including the EOB char. */
                int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

                /* Undo the effects of YY_DO_BEFORE_ACTION. */
                *yy_cp = (yy_hold_char);
                YY_RESTORE_YY_MORE_OFFSET

                if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
                        {
                        /* We're scanning a new file or input source.  It's
                         * possible that this happened because the user
                         * just pointed yyin at a new source and called
                         * yylex().  If so, then we have to assure
                         * consistency between YY_CURRENT_BUFFER and our
                         * globals.  Here is the right place to do so, because
                         * this is the first action (other than possibly a
                         * back-up) that will match for the new input source.
                         */
                        (yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
                        YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
                        YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
                        }

                /* Note that here we test for yy_c_buf_p "<=" to the position
                 * of the first EOB in the buffer, since yy_c_buf_p will
                 * already have been incremented past the NUL character
                 * (since all states make transitions on EOB to the
                 * end-of-buffer state).  Contrast this with the test
                 * in input().
                 */
                if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
                        { /* This was really a NUL. */
                        yy_state_type yy_next_state;

                        (yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

                        yy_current_state = yy_get_previous_state(  );

                        /* Okay, we're now positioned to make the NUL
                         * transition.  We couldn't have
                         * yy_get_previous_state() go ahead and do it
                         * for us because it doesn't know how to deal
                         * with the possibility of jamming (and we don't
                         * want to build jamming into it because then it
                         * will run more slowly).
                         */

                        yy_next_state = yy_try_NUL_trans( yy_current_state );

                        yy_bp = (yytext_ptr) + YY_MORE_ADJ;

                        if ( yy_next_state )
                                {
                                /* Consume the NUL. */
                                yy_cp = ++(yy_c_buf_p);
                                yy_current_state = yy_next_state;
                                goto yy_match;
                                }

                        else
                                {
                                yy_cp = (yy_c_buf_p);
                                goto yy_find_action;
                                }
                        }

                else switch ( yy_get_next_buffer(  ) )
                        {
                        case EOB_ACT_END_OF_FILE:
                                {
                                (yy_did_buffer_switch_on_eof) = 0;

                                if ( yywrap( ) )
                                        {
                                        /* Note: because we've taken care in
                                         * yy_get_next_buffer() to have set up
                                         * yytext, we can now set up
                                         * yy_c_buf_p so that if some total
                                         * hoser (like flex itself) wants to
                                         * call the scanner after we return the
                                         * YY_NULL, it'll still work - another
                                         * YY_NULL will get returned.
                                         */
                                        (yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

                                        yy_act = YY_STATE_EOF(YY_START);
                                        goto do_action;
                                        }

                                else
                                        {
                                        if ( ! (yy_did_buffer_switch_on_eof) )
                                                YY_NEW_FILE;
                                        }
                                break;
                                }

                        case EOB_ACT_CONTINUE_SCAN:
                                (yy_c_buf_p) =
                                        (yytext_ptr) + yy_amount_of_matched_text;

                                yy_current_state = yy_get_previous_state(  );

                                yy_cp = (yy_c_buf_p);
                                yy_bp = (yytext_ptr) + YY_MORE_ADJ;
                                goto yy_match;

                        case EOB_ACT_LAST_MATCH:
                                (yy_c_buf_p) =
                                &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

                                yy_current_state = yy_get_previous_state(  );

                                yy_cp = (yy_c_buf_p);
                                yy_bp = (yytext_ptr) + YY_MORE_ADJ;
                                goto yy_find_action;
                        }
                break;
                }

        default:
                YY_FATAL_ERROR(
                        "fatal flex scanner internal error--no action found" );
        } /* end of action switch */
                } /* end of scanning one token */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *      EOB_ACT_LAST_MATCH -
 *      EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *      EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
        register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
        register char *source = (yytext_ptr);
        register int number_to_move, i;
        int ret_val;

        if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
                YY_FATAL_ERROR(
                "fatal flex scanner internal error--end of buffer missed" );

        if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
                { /* Don't try to fill the buffer, so this is an EOF. */
                if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
                        {
                        /* We matched a single character, the EOB, so
                         * treat this as a final EOF.
                         */
                        return EOB_ACT_END_OF_FILE;
                        }

                else
                        {
                        /* We matched some text prior to the EOB, first
                         * process it.
                         */
                        return EOB_ACT_LAST_MATCH;
                        }
                }

        /* Try to read more data. */

        /* First move last chars to start of buffer. */
        number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

        for ( i = 0; i < number_to_move; ++i )
                *(dest++) = *(source++);

        if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
                /* don't do the read, it's not guaranteed to return an EOF,
                 * just force an EOF
                 */
                YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

        else
                {
                        int num_to_read =
                        YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

                while ( num_to_read <= 0 )
                        { /* Not enough room in the buffer - grow it. */

                        /* just a shorter name for the current buffer */
                        YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

                        int yy_c_buf_p_offset =
                                (int) ((yy_c_buf_p) - b->yy_ch_buf);

                        if ( b->yy_is_our_buffer )
                                {
                                int new_size = b->yy_buf_size * 2;

                                if ( new_size <= 0 )
                                        b->yy_buf_size += b->yy_buf_size / 8;
                                else
                                        b->yy_buf_size *= 2;

                                b->yy_ch_buf = (char *)
                                        /* Include room in for 2 EOB chars. */
                                        yyrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
                                }
                        else
                                /* Can't grow it, we don't own it. */
                                b->yy_ch_buf = 0;

                        if ( ! b->yy_ch_buf )
                                YY_FATAL_ERROR(
                                "fatal error - scanner input buffer overflow" );

                        (yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

                        num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
                                                number_to_move - 1;

                        }

                if ( num_to_read > YY_READ_BUF_SIZE )
                        num_to_read = YY_READ_BUF_SIZE;

                /* Read in more data. */
                YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
                        (yy_n_chars), (size_t) num_to_read );

                YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
                }

        if ( (yy_n_chars) == 0 )
                {
                if ( number_to_move == YY_MORE_ADJ )
                        {
                        ret_val = EOB_ACT_END_OF_FILE;
                        yyrestart(yyin  );
                        }

                else
                        {
                        ret_val = EOB_ACT_LAST_MATCH;
                        YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
                                YY_BUFFER_EOF_PENDING;
                        }
                }

        else
                ret_val = EOB_ACT_CONTINUE_SCAN;

        if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
                /* Extend the array by 50%, plus the number we really need. */
                yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
                YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
                if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
                        YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
        }

        (yy_n_chars) += number_to_move;
        YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
        YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

        (yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

        return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
        register yy_state_type yy_current_state;
        register char *yy_cp;
    
        yy_current_state = (yy_start);
        yy_current_state += YY_AT_BOL();

        for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
                {
                register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
                if ( yy_accept[yy_current_state] )
                        {
                        (yy_last_accepting_state) = yy_current_state;
                        (yy_last_accepting_cpos) = yy_cp;
                        }
                while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
                        {
                        yy_current_state = (int) yy_def[yy_current_state];
                        if ( yy_current_state >= 422 )
                                yy_c = yy_meta[(unsigned int) yy_c];
                        }
                yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
                }

        return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *      next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
        register int yy_is_jam;
        register char *yy_cp = (yy_c_buf_p);

        register YY_CHAR yy_c = 1;
        if ( yy_accept[yy_current_state] )
                {
                (yy_last_accepting_state) = yy_current_state;
                (yy_last_accepting_cpos) = yy_cp;
                }
        while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
                {
                yy_current_state = (int) yy_def[yy_current_state];
                if ( yy_current_state >= 422 )
                        yy_c = yy_meta[(unsigned int) yy_c];
                }
        yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
        yy_is_jam = (yy_current_state == 421);

        return yy_is_jam ? 0 : yy_current_state;
}

    static void yyunput (int c, register char * yy_bp )
{
        register char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

        /* undo effects of setting up yytext */
        *yy_cp = (yy_hold_char);

        if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
                { /* need to shift things up to make room */
                /* +2 for EOB chars. */
                register int number_to_move = (yy_n_chars) + 2;
                register char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
                                        YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
                register char *source =
                                &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

                while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
                        *--dest = *--source;

                yy_cp += (int) (dest - source);
                yy_bp += (int) (dest - source);
                YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
                        (yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

                if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
                        YY_FATAL_ERROR( "flex scanner push-back overflow" );
                }

        *--yy_cp = (char) c;

        (yytext_ptr) = yy_bp;
        (yy_hold_char) = *yy_cp;
        (yy_c_buf_p) = yy_cp;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
        int c;
    
        *(yy_c_buf_p) = (yy_hold_char);

        if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
                {
                /* yy_c_buf_p now points to the character we want to return.
                 * If this occurs *before* the EOB characters, then it's a
                 * valid NUL; if not, then we've hit the end of the buffer.
                 */
                if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
                        /* This was really a NUL. */
                        *(yy_c_buf_p) = '\0';

                else
                        { /* need more input */
                        int offset = (yy_c_buf_p) - (yytext_ptr);
                        ++(yy_c_buf_p);

                        switch ( yy_get_next_buffer(  ) )
                                {
                                case EOB_ACT_LAST_MATCH:
                                        /* This happens because yy_g_n_b()
                                         * sees that we've accumulated a
                                         * token and flags that we need to
                                         * try matching the token before
                                         * proceeding.  But for input(),
                                         * there's no matching to consider.
                                         * So convert the EOB_ACT_LAST_MATCH
                                         * to EOB_ACT_END_OF_FILE.
                                         */

                                        /* Reset buffer status. */
                                        yyrestart(yyin );

                                        /*FALLTHROUGH*/

                                case EOB_ACT_END_OF_FILE:
                                        {
                                        if ( yywrap( ) )
                                                return EOF;

                                        if ( ! (yy_did_buffer_switch_on_eof) )
                                                YY_NEW_FILE;
#ifdef __cplusplus
                                        return yyinput();
#else
                                        return input();
#endif
                                        }

                                case EOB_ACT_CONTINUE_SCAN:
                                        (yy_c_buf_p) = (yytext_ptr) + offset;
                                        break;
                                }
                        }
                }

        c = *(unsigned char *) (yy_c_buf_p);    /* cast for 8-bit char's */
        *(yy_c_buf_p) = '\0';   /* preserve yytext */
        (yy_hold_char) = *++(yy_c_buf_p);

        YY_CURRENT_BUFFER_LVALUE->yy_at_bol = (c == '\n');

        return c;
}
#endif  /* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
        if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
                YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer(yyin,YY_BUF_SIZE );
        }

        yy_init_buffer(YY_CURRENT_BUFFER,input_file );
        yy_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
        /* TODO. We should be able to replace this entire function body
         * with
         *              yypop_buffer_state();
         *              yypush_buffer_state(new_buffer);
     */
        yyensure_buffer_stack ();
        if ( YY_CURRENT_BUFFER == new_buffer )
                return;

        if ( YY_CURRENT_BUFFER )
                {
                /* Flush out information for old buffer. */
                *(yy_c_buf_p) = (yy_hold_char);
                YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
                YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
                }

        YY_CURRENT_BUFFER_LVALUE = new_buffer;
        yy_load_buffer_state( );

        /* We don't actually know whether we did this switch during
         * EOF (yywrap()) processing, but the only time this flag
         * is looked at is after yywrap() is called, so it's safe
         * to go ahead and always set it.
         */
        (yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
        (yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
        (yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
        yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
        (yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
        YY_BUFFER_STATE b;
    
        b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
        if ( ! b )
                YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

        b->yy_buf_size = size;

        /* yy_ch_buf has to be 2 characters longer than the size given because
         * we need to put in 2 end-of-buffer characters.
         */
        b->yy_ch_buf = (char *) yyalloc(b->yy_buf_size + 2  );
        if ( ! b->yy_ch_buf )
                YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

        b->yy_is_our_buffer = 1;

        yy_init_buffer(b,file );

        return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
        if ( ! b )
                return;

        if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
                YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

        if ( b->yy_is_our_buffer )
                yyfree((void *) b->yy_ch_buf  );

        yyfree((void *) b  );
}

#ifndef __cplusplus
extern int isatty (int );
#endif /* __cplusplus */
    
/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
        int oerrno = os_getErrno();
    
        yy_flush_buffer(b );

        b->yy_input_file = file;
        b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
        os_setErrno(oerrno);
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
        if ( ! b )
                return;

        b->yy_n_chars = 0;

        /* We always need two end-of-buffer characters.  The first causes
         * a transition to the end-of-buffer state.  The second causes
         * a jam in that state.
         */
        b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
        b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

        b->yy_buf_pos = &b->yy_ch_buf[0];

        b->yy_at_bol = 1;
        b->yy_buffer_status = YY_BUFFER_NEW;

        if ( b == YY_CURRENT_BUFFER )
                yy_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
        if (new_buffer == NULL)
                return;

        yyensure_buffer_stack();

        /* This block is copied from yy_switch_to_buffer. */
        if ( YY_CURRENT_BUFFER )
                {
                /* Flush out information for old buffer. */
                *(yy_c_buf_p) = (yy_hold_char);
                YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
                YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
                }

        /* Only push if top exists. Otherwise, replace top. */
        if (YY_CURRENT_BUFFER)
                (yy_buffer_stack_top)++;
        YY_CURRENT_BUFFER_LVALUE = new_buffer;

        /* copied from yy_switch_to_buffer. */
        yy_load_buffer_state( );
        (yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
        if (!YY_CURRENT_BUFFER)
                return;

        yy_delete_buffer(YY_CURRENT_BUFFER );
        YY_CURRENT_BUFFER_LVALUE = NULL;
        if ((yy_buffer_stack_top) > 0)
                --(yy_buffer_stack_top);

        if (YY_CURRENT_BUFFER) {
                yy_load_buffer_state( );
                (yy_did_buffer_switch_on_eof) = 1;
        }
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
        int num_to_alloc;
    
        if (!(yy_buffer_stack)) {

                /* First allocation is just for 2 elements, since we don't know if this
                 * scanner will even need a stack. We use 2 instead of 1 to avoid an
                 * immediate realloc on the next call.
         */
                num_to_alloc = 1;
                (yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
                                                                (num_to_alloc * sizeof(struct yy_buffer_state*)
                                                                );
                if ( ! (yy_buffer_stack) )
                        YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );
                                                                  
                memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
                                
                (yy_buffer_stack_max) = num_to_alloc;
                (yy_buffer_stack_top) = 0;
                return;
        }

        if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

                /* Increase the buffer to prepare for a possible push. */
                int grow_size = 8 /* arbitrary grow size */;

                num_to_alloc = (yy_buffer_stack_max) + grow_size;
                (yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
                                                                ((yy_buffer_stack),
                                                                num_to_alloc * sizeof(struct yy_buffer_state*)
                                                                );
                if ( ! (yy_buffer_stack) )
                        YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

                /* zero only the new slots.*/
                memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
                (yy_buffer_stack_max) = num_to_alloc;
        }
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
        YY_BUFFER_STATE b;
    
        if ( size < 2 ||
             base[size-2] != YY_END_OF_BUFFER_CHAR ||
             base[size-1] != YY_END_OF_BUFFER_CHAR )
                /* They forgot to leave room for the EOB's. */
                return 0;

        b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
        if ( ! b )
                YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

        b->yy_buf_size = size - 2;      /* "- 2" to take care of EOB's */
        b->yy_buf_pos = b->yy_ch_buf = base;
        b->yy_is_our_buffer = 0;
        b->yy_input_file = 0;
        b->yy_n_chars = b->yy_buf_size;
        b->yy_is_interactive = 0;
        b->yy_at_bol = 1;
        b->yy_fill_buffer = 0;
        b->yy_buffer_status = YY_BUFFER_NEW;

        yy_switch_to_buffer(b  );

        return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (yyconst char * yystr )
{
    
        return yy_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (yyconst char * yybytes, int  _yybytes_len )
{
        YY_BUFFER_STATE b;
        char *buf;
        yy_size_t n;
        int i;
    
        /* Get memory for full buffer, including space for trailing EOB's. */
        n = _yybytes_len + 2;
        buf = (char *) yyalloc(n  );
        if ( ! buf )
                YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

        for ( i = 0; i < _yybytes_len; ++i )
                buf[i] = yybytes[i];

        buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

        b = yy_scan_buffer(buf,n );
        if ( ! b )
                YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

        /* It's okay to grow etc. this buffer, and we should throw it
         * away when we're done.
         */
        b->yy_is_our_buffer = 1;

        return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
        (void) fprintf( stderr, "%s\n", msg );
        exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
        do \
                { \
                /* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
                yytext[yyleng] = (yy_hold_char); \
                (yy_c_buf_p) = yytext + yyless_macro_arg; \
                (yy_hold_char) = *(yy_c_buf_p); \
                *(yy_c_buf_p) = '\0'; \
                yyleng = yyless_macro_arg; \
                } \
        while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
        
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void yyset_lineno (int  line_number )
{
    
    yylineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  in_str )
{
        yyin = in_str ;
}

void yyset_out (FILE *  out_str )
{
        yyout = out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  bdebug )
{
        yy_flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = (FILE *) 0;
    yyout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
        while(YY_CURRENT_BUFFER){
                yy_delete_buffer(YY_CURRENT_BUFFER  );
                YY_CURRENT_BUFFER_LVALUE = NULL;
                yypop_buffer_state();
        }

        /* Destroy the stack itself. */
        yyfree((yy_buffer_stack) );
        (yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
        register int i;
        for ( i = 0; i < n; ++i )
                s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
        register int n;
        for ( n = 0; s[n]; ++n )
                ;

        return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
        return (void *) malloc( size );
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
        /* The cast to (char *) in the following accommodates both
         * implementations that use char* generic pointers, and those
         * that use void* generic pointers.  It works with the latter
         * because both ANSI C and C++ allow castless assignment from
         * any pointer type to void*, and deal with argument conversions
         * as though doing an assignment.
         */
        return (void *) realloc( (char *) ptr, size );
}

void yyfree (void * ptr )
{
        free( (char *) ptr );   /* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 339 "idl.ll"


        /* subroutines */

/*
 * Strip down a name to the last component, i.e. everything after the last
 * '/' character
 */
static char *
stripped_name(UTL_String *fn)
{
    char        *n = fn->get_string();
    long        l;

    if (n == NULL)
        return NULL;
    l = strlen(n);
    for (n += l; l > 0 && *n != '/' && *n != '\\'; l--, n--);
    if (*n == '/' || *n == '\\') n++;
    return n;
}

/*
 * Parse a #line statement generated by the C preprocessor
 */

static void idl_parse_line_and_file (char *buf)
{
  char * r = buf;
  char * h;
  UTL_String * nm;

  /* Skip initial '#' */

  if (*r != '#')
  {
    return;
  }

  /* Find line number */
  for (r++; *r == ' ' || *r == '\t'; r++);
  h = r;
  for (; *r != '\0' && *r != ' ' && *r != '\t'; r++);
  *r++ = 0;
  idl_global->set_lineno(idl_atoi(h, 10));
  
  /* Find file name, if present */
  for (; *r != '"'; r++)
  {
    if (*r == '\n' || *r == '\0')
      return;
  }
  h = ++r;
  for (; *r != '"'; r++);
  *r = 0;

  if (*h == '\0')
  {
    idl_global->set_filename (new UTL_String ("standard input"));
  }
  else
  {
    // figure out whether to include this file...
    UTL_String *new_file = new UTL_String (h);

    idl_global->set_filename (new_file);
    // hide that fact that we are dealing with a temp file
    if(idl_global->filename()->compare(idl_global->real_filename()))
    {
      idl_global->set_filename (idl_global->main_filename());
      idl_global->set_in_main_file (true);
    }
    else
    {
      idl_global->set_in_main_file (false);
    }
  }

  /*
   * If it's an import file store the stripped name for the BE to use
   */
  if 
  (
     !(idl_global->in_main_file ()) &&
     idl_global->imported () &&
     (fstackdepth < 2)
  ) 
  {
    nm = new UTL_String (stripped_name (idl_global->filename ()));
    idl_global->store_include_file_name (nm);
  }
}
    
/*
 * idl_atoi - Convert a string of digits into an integer according to base b
 */
static long
idl_atoi(char *s, long b)
{
        long    r = 0;
        long    negative = 0;

        if (*s == '-') {
          negative = 1;
          s++;
        }
        if (b == 8 && *s == '0')
          s++;
        else if (b == 16 && *s == '0' && (*(s + 1) == 'x' || *(s + 1) == 'X'))
          s += 2;

        for (; *s; s++)
          if (*s <= '9' && *s >= '0')
            r = (r * b) + (*s - '0');
          else if (b > 10 && *s <= 'f' && *s >= 'a')
            r = (r * b) + (*s - 'a' + 10);
          else if (b > 10 && *s <= 'F' && *s >= 'A')
            r = (r * b) + (*s - 'A' + 10);
          else
            break;

        if (negative)
          r *= -1;

        return r;
}

/*
 * Convert (some) escaped characters into their ascii values
 */
static char
idl_escape_reader(
    char *str
)
{
    if (str[0] != '\\') {
        return str[0];
    }

    switch (str[1]) {
      case 'n':
        return '\n';
      case 't':
        return '\t';
      case 'v':
        return '\v';
      case 'b':
        return '\b';
      case 'r':
        return '\r';
      case 'f':
        return '\f';
      case 'a':
        return '\a';
      case '\\':
        return '\\';
      case '\?':
        return '?';
      case '\'':
        return '\'';
      case '"':
        return '"';
      case 'x':
        {
         int i;
            // hex value
            for (i = 2; str[i] != '\0' && isxdigit(str[i]); i++) {
                continue;
            }
            char save = str[i];
            str[i] = '\0';
            char out = (char)idl_atoi(&str[2], 16);
            str[i] = save;
            return out;
        }
        break;
      default:
        // check for octal value
        if (str[1] >= '0' && str[1] <= '7')
        {
         int i;
            for (i = 1; str[i] >= '0' && str[i] <= '7'; i++) {
                continue;
            }
            char save = str[i];
            str[i] = '\0';
            char out = (char)idl_atoi(&str[1], 8);
            str[i] = save;
            return out;
        } else {
          return str[1] - 'a';
        }
        break;
    }
}

